Documentation
¶
Overview ¶
bited-utils is a set of pipeline helpers and utilities for building fonts from bited BDFs.
Documentation for each utility:
Index ¶
- Constants
- Variables
- func Check(err error)
- func PropString(v any) string
- func WcWidth(r rune, nerd bool) int
- type BDF
- type BmI
- type Glyph
- func (glyph *Glyph) Bits() iter.Seq2[BmI[[2]int], bool]
- func (glyph *Glyph) Bytes() iter.Seq2[BmI[[2]int], byte]
- func (glyph *Glyph) Copy() *Glyph
- func (glyph *Glyph) Flip(i int, j int)
- func (glyph *Glyph) Get(i int, j int) (bool, bool)
- func (glyph *Glyph) H() int
- func (glyph *Glyph) Hex2Row(i int, s string) error
- func (glyph *Glyph) Name() string
- func (glyph *Glyph) NewBm(w int, h int)
- func (glyph *Glyph) Row32() int
- func (glyph *Glyph) Row8() int
- func (glyph *Glyph) Rows() iter.Seq2[int, []uint32]
- func (glyph *Glyph) SWidth(bdf *BDF) int
- func (glyph *Glyph) Scale(scale int)
- func (glyph *Glyph) Set(i int, j int, b bool) bool
- func (glyph *Glyph) SetRect(oi int, oj int, w int, h int, b bool)
- func (glyph *Glyph) Uints() iter.Seq2[BmI[[2]int], uint32]
- func (glyph *Glyph) W() int
- func (glyph *Glyph) Write(bdf *BDF, w io.Writer) error
- func (glyph *Glyph) WriteBm(w io.Writer) error
- type XLFD
Constants ¶
const ( PRE = iota X PROPS CHARS CHAR BM POST )
Variables ¶
var NerdFont = &unicode.RangeTable{ R16: []unicode.Range16{ {0x23fb, 0x23fe, 1}, {0x2b58, 0x2b58, 1}, {0xe000, 0xe00a, 1}, {0xe0a0, 0xe0a3, 1}, {0xe0b0, 0xe0c8, 1}, {0xe0ca, 0xe0ca, 1}, {0xe0cc, 0xe0d7, 1}, {0xe200, 0xe2a9, 1}, {0xe300, 0xe3e3, 1}, {0xe5fa, 0xe6b7, 1}, {0xe700, 0xe8ef, 1}, {0xea60, 0xec1e, 1}, {0xed00, 0xefce, 1}, {0xf000, 0xf381, 1}, {0xf400, 0xf533, 1}, }, R32: []unicode.Range32{ {0xf0001, 0xf1af0, 1}, }, }
Functions ¶
func PropString ¶ added in v1.2.1
Types ¶
type BDF ¶ added in v1.2.1
type BDF struct {
*XLFD
Props *orderedmap.OrderedMap[string, any]
Glyphs []*Glyph
// contains filtered or unexported fields
}
func (*BDF) CleanProps ¶ added in v1.2.1
func (bdf *BDF) CleanProps()
type XLFD ¶ added in v1.2.1
type XLFD struct {
Foundry string
Family string
Weight string
Slant string
Setwidth string
AddStyle string
PxSize int
Res struct {
X int
Y int
}
Spacing string
// contains filtered or unexported fields
}
func (*XLFD) Props ¶ added in v1.2.1
func (xlfd *XLFD) Props() *orderedmap.OrderedMap[string, any]
func (*XLFD) ValidateSlant ¶ added in v1.2.1
func (*XLFD) ValidateSpacing ¶ added in v1.2.1
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
bited-bbl is a command for proportionalizing bited BDFs.
|
bited-bbl is a command for proportionalizing bited BDFs. |
|
bited-build generates vector (TTF, WOFF2) and bitmap (BDF, PCF, OTB, DFONT) fonts from bited BDFs.
|
bited-build generates vector (TTF, WOFF2) and bitmap (BDF, PCF, OTB, DFONT) fonts from bited BDFs. |
|
lib
Package bitedbuild is the backing library for bited-build.
|
Package bitedbuild is the backing library for bited-build. |
|
bited-clr is a TUI tool for fine-tuned coloring of TXT/CLR pairs.
|
bited-clr is a TUI tool for fine-tuned coloring of TXT/CLR pairs. |
|
bited-img generates image specimens for bited BDFs.
|
bited-img generates image specimens for bited BDFs. |
|
lib
Package bitedimg is the backing library for bited-img.
|
Package bitedimg is the backing library for bited-img. |
|
bited-scale is a command for scaling bited BDFs.
|
bited-scale is a command for scaling bited BDFs. |
Click to show internal directories.
Click to hide internal directories.